import request from '@/utils/request'

// 查询今日销售总金额，总升数
export function listSum(query) {
  return request({
    url: '/station/order/selectDaySources',
    method: 'get',
    params: query
  })
}

export function listOilType(query) {
  return request({
    url: '/station/order/selectOilTypeSources',
    method: 'get',
    params: query
  })
}
export function listViewData(query) {
  return request({
    url: '/station/order/selectOverViewData',
    method: 'get',
    params: query
  })
}

// 查询订单支付详细
export function getOrder(orderId) {
  return request({
    url: '/station/order/' + orderId,
    method: 'get'
  })
}

export function listDayReport(query) {
  return request({
    url: '/station/order/selectDayReport',
    method: 'get',
    params: query
  })
}
export function getDetails(query) {
  return request({
    url: '/station/order/list',
    method: 'get',
    params: query
  })
}
export function listQydata92(query) {
  return request({
    url: '/station/order/listQydata92',
    method: 'get',
    params: query
  })
}
export function listQydata95(query) {
  return request({
    url: '/station/order/listQydata95',
    method: 'get',
    params: query
  })
}
export function listQydata97(query) {
  return request({
    url: '/station/order/listQydata97',
    method: 'get',
    params: query
  })
}
export function listXdata(query) {
  return request({
    url: '/station/order/listXdata',
    method: 'get',
    params: query
  })
}

